@@ -1,5 +1,5 @@
 from .auth import AuthenticatorMixin
 from .handler import HandlerMixin
-from .emmiter import EmitterMixin
+from .emitter import EmitterMixin
 from .parser import ParserMixin
 from .throttle import ThrottleMixin
